@@ -1,6 +1,6 @@
-from jobx.task import Task
+from .cmd import build_cmd_task
+from .python import build_python_task
 from .task_group import build_task_group
-
 class Builder:
     @staticmethod
     def build(task, name,task_spec):
