@@ -2,6 +2,8 @@ import os
 from jobx.utils import  generate_env_string
 from jobx.task import Task
 
+from .registry import register
+@register("cmd")
 def build_cmd_task(task:dict, name):
         command = task['command']
         env = task.get('env',{})
