@@ -2,7 +2,8 @@ from jobx.utils import import_module, generate_env_string
 from jobx.task import Task
 import os
 import sys
-
+from .registry import register
+@register("python")
 def build_python_task(task:dict, name):
     python_file = task['path']
     args = task.get('args',[])
