@@ -1,5 +1,5 @@
 from jobx.task import Task
-from .factory import builder_factory
+from .registry import builder_factory
 def build_task(task, name):
     assert isinstance(task, dict)
     task_type = task.get('type', 'python')
