@@ -1,5 +1,8 @@
 from fnmatch import fnmatch
 from .task import build_task
+from .registry import register
+
+@register("task-group")
 def build_task_group(cfg, name, task_spec=None):
     '''
     task_spec example: 'train-*,test-*'
